(configure opts)Pass a map to set various options for Chroma and how the library
works. Every option also can be configured by a CHROMA_*
environment variable of the same name.
Configurable options are:
protocol: http/https. Default http.host: Chroma host. Required, no default.port: HTTP port. Default 8000.api-version: API version, "v1" or "v2". Default "v2".timeout: HTTP timeout in milliseconds. Default 10000.api-key: Chroma API key. Required for hosted Chroma, no default.tenant: Unique tenant id. Default "default_tenant".database: Database name. Default "default_database".allow-reset: Whether it is possible delete all data via the API. Defaults to false.Pass a map to set various options for Chroma and how the library works. Every option also can be configured by a `CHROMA_*` environment variable of the same name. Configurable options are: - `protocol`: http/https. Default http. - `host`: Chroma host. Required, no default. - `port`: HTTP port. Default 8000. - `api-version`: API version, "v1" or "v2". Default "v2". - `timeout`: HTTP timeout in milliseconds. Default 10000. - `api-key`: Chroma API key. Required for hosted Chroma, no default. - `tenant`: Unique tenant id. Default "default_tenant". - `database`: Database name. Default "default_database". - `allow-reset`: Whether it is possible delete all data via the API. Defaults to false.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |